var users = users || {};

(function($) {

    "use strict";

    var KEY_ESC   = 27;
    var KEY_TAB   = 9;
    var KEY_ENTER = 13

    $.extend($.expr[':'], {
        Contains: function(el, index, meta) {
            var reg = new RegExp('^' + meta[3].toUpperCase(), 'i');
            return reg.test($(el).text().trim().toUpperCase());
        }
    });

    var nm = {

        init: function(opt) {

            this.my_mess           = $('.my_messages a');
            this.oldMsgCount       = 0;
            this.listenTimer       = 0;
            this.messageLastId     = false;
            this.messageFirstId    = 0;
            this.listenEnabled     = true;
            this.contactslock      = false;
            this.lockSend          = false;
            this.isMobile          = isMobile.any;
            this.currContact       = false;
            this.lastContactId     = false;
            this.contacts          = {};

            $.extend(this, opt);

            this.sound.init();
            this.emoji.init();

            if (this.isMobile) {
                this.viewport.init();
            }

            var recipientId = 0;

            $.extend(users, {
                sendMess: function(id) {
                    recipientId = id;
                    nm.modal.show();
                    return false;
                },
                acceptFriend: function(id, link) {
                    $.post('/users/' + id + '/friendship.html', {}, function(data) {
                        nm.messDelete.call(link);
                        if (data.error == false) {
                            core.alert(data.text, 'Уведомление');
                        } else {
                            core.alert(data.text, 'Предупреждение');
                        }
                    }, 'json');
                },
                rejectFriend: function(id, link) {
                    $.post('/users/' + id + '/nofriends.html', {}, function(data) {
                        if (data.error == false) {
                            nm.messDelete.call(link);
                            core.alert(data.text, 'Уведомление');
                        }
                    }, 'json');
                }
            });

            // Навешиваемся на ссылку "Сообщения"
            $('body').on('click', 'a[href$=\'/messages.html\'], a[href$=\'/messages-notices.html\']', function() {
                nm.modal.show();
                return false;
            });

            // Срабатывает при открытии модального окна
            $('body').on('nm_opened', '#nm-overlay', function() {

                // Показ, скрытие списка контактов
                $(this).on('click', '.nm-toggle', function() {
                    nm.modal.$el.toggleClass('nm-contacts-open');
                });

                // Закрыть окно
                $(this).on('click', '.nm-close', function() {
                    nm.modal.hide();
                });

                if (nm.closeOverlay) {
                    $(this).on('click', function(e) {
                        e = e.originalEvent || e;
                        var target = e.originalTarget || e.target || window;
                        if (target == $('#nm-overlay')[0]) {
                            nm.modal.hide();
                        }
                    });
                }

                // Открыть переписку с контактом
                $(this).on('click', '.user_contact', function() {
                    nm.selectContact($(this).attr('rel'));
                });

                // Отправка сообщения при нажатии на кнопку
                $(this).on('click', '#nm-send', function() {
                    nm.sendMessage(false);
                });

                // Массовая отправка сообщений
                $(this).on('click', '#nm-mass-send', function() {
                    nm.sendMessage(true);
                });

                $(this).on('keydown', '#nm-msg-field', function(e) {
                    if (nm.sendOnEnter) {
                        if (e.keyCode === KEY_ENTER) {
                            if (e.ctrlKey) {
                                $(this).val($(this).val() + "\r");
                            } else {
                                nm.sendMessage(false);
                            }
                        }
                    } else {
                        if (e.keyCode === KEY_ENTER && e.ctrlKey) {
                            nm.sendMessage(false);
                        }
                    }
                });

                // Сохранение текста в LocalStorage
                $(this).on('blur change keyup', '#nm-msg-field', function(e) {
                    nm.updateDraft();
                });

                // Показать, скрыть смайлы
                $(this).on('click', '#nm-smiles-btn', function() {
                    nm.emoji.toggle();
                });

                // Отмечать сообщение как прочитанное при наведении на него курсора
                $(this).on('mouseenter click', '.conversation-item.new', function() {
                    nm.setMsgReaded($(this).attr('rel'));
                });

                // Удаление сообщения
                $(this).on('click', '.conversation-item .delete', function() {
                    nm.messDelete.call(this);
                });

                // Удаление контакта
                $(this).on('click', '.user_contact .delete', function(e) {
                    nm.contactDelete($(this).parent());
                    e.stopPropagation();
                });

                // Поиск контакта
                $(this).on('keyup', '#nm-search-inp', function() {
                    nm.contactFilter();
                });

                // Очистить строку поиска
                $(this).on('click', '#nm-search-clr', function() {
                    $('#nm-userlist .user_contact').slideDown();
                    $('#nm-search-inp').val('');
                    $(this).hide();
                });

                nm.viewport.change();
                nm.start(recipientId);
            });

            // Обнуление переменных при закрытии окна (временно)
            $('body').on('nm_closed', '#nm-overlay', function() {
                nm.viewport.restore();
                nm.chatHeight = 0;
                nm.userListHeight = 0;
                nm.contactslock = false;
                nm.lockSend = false;
                nm.older_loading = false;
                nm.contacts = {};
                nm.currContact = false;
                nm.lastContactId = false;
                nm.messageLastId = false;
                nm.messageFirstId = 0;
            });

            var resize_events = 'resize' + (nm.isMobile) ? ' orientationchange' : '';

            // перерасчет окна при ресайзе окна или при смене ориентации
            $(window).bind('resize', function() {
                if (nm.modal.visible) {
                    nm.modal.onDimensions();
                }
            });

            // Закрытие по "Esc" панели для вставки фото, или выбора из альбома
            $('body').on('keydown', function(e) {
                if (nm.modal.visible && e.keyCode === KEY_ESC) {
                    var $panelfoto = $('#nm-panelfoto', nm.modal.$el);
                    var $imginsert = $('#imginsert', nm.modal.$el);

                    if ($panelfoto.is(':visible')) $panelfoto.hide();
                    if ($imginsert.is(':visible')) $imginsert.hide();
                }
            });

            nm.updateMsgCounter();
            this.listen();

        },

        start: function(recipient_id) {

            var select_index = 0;

            nm.listenEnabled = false;

            nm.post('getСontacts', {recipient_id: recipient_id}, function(data) {
                if (data.contacts.length) {
                    $.each(data.contacts, function() {
                        nm.addContact(this);
                    });

                    nm.lastContactId = data.last_contact;

                    $('.nm-content').show();

                    if (data.contacts.length > 1 && data.contacts[0].id < 0 && data.contacts[0].new_messages == 0) {
                        select_index = 1;
                    }

                    if ($(window).width() > 479) {
                        nm.selectContact(recipient_id || data.contacts[select_index].id);
                    }

                    nm.modal.$el.addClass('nm-contacts-loaded');
                    nm.modal.onDimensions();
                } else {
                    $('#nm-not-selected').hide();
                    $('.nm-nomess').show();
                }
     
                nm.listenEnabled = true;

                $('.nm-loading').hide();
            });

        },

        addContact: function(contact) {

            nm.contacts[contact.id] = contact;
            $('#nm-userlist').append(nm.render.contact(contact));

        },

        setStatus: function(id, status) {

            $('#nm-contact' + id)[(status == '1' ? 'add' : 'remove') + 'Class']('_online');

        },

        setMsgCounter: function(id, count) {

            var $contact = $('#nm-contact' + id);
            var $counter = $('.counter', $contact);

            var old_counter = $counter.length ? $counter.attr('rel') : 0;

            if ($counter.length) $counter.remove();

            if (count > 0) {
                $contact.prepend('<span class="counter" rel="' + count + '">+ ' + count + '</span>');
            }

            if (count > old_counter) {
                nm.topContact(id);
            }

        },

        selectContact: function(id) {

            if (nm.contactslock) return;

            var contact = $('#nm-contact' + id);
            var draft = (nm.ls.get('nm_draft_' + nm.user.id + '_' + id) || {})['text'] || '';

            nm.modal.$el.addClass('nm-selected nm-contacts-open');

            if (contact.hasClass('selected')) return;

            $('#nm-userlist li').removeClass('selected');
            contact.addClass('selected');

            nm.contactslock   = true;
            nm.listenEnabled  = false;
            nm.currContact    = nm.contacts[id];
            nm.messageLastId  = false;
            nm.messageFirstId = false;

            $('#nm-chat-wrapper, #nm-composer').hide();
            $('#nm-msg-loading').show();
            $('#nm-chat').html('').unbind('scroll');
            $('#nm-msg-field').val(draft);

            nm.post('getMessages', {contact_id: id}, function(data) {
                $('#nm-msg-loading').hide();
                $('#nm-chat-wrapper').show();

                if (id > 0) $('#nm-composer').show();

                nm.contactslock  = false;
                nm.listenEnabled = true;

                if (data.messages.length) {

                    $.each(data.messages, function() {
                        nm.appendMessage(this);
                    });

                    nm.messageLastId = data.messages[data.messages.length - 1].id;

                    if (data.has_older) {
                        nm.messageFirstId = data.messages[0].id;
                        $('#nm-chat').bind('scroll', function () {
                            if ($(this).scrollTop() <= 5) nm.showOlder.call(this);
                        });
                    }

                }

                nm.modal.onDimensions();

                $('#nm-chat').waitForImages({
                    finished: function() {
                        nm.scrollChat();
                    },
                    waitForAll: true
                });
            });

        },

        topContact: function(id) {

            var $contact = $('#nm-contact' + id),
                $container = $contact.parent(),
                $noticeCnt = $('#nm-contact-1');

            if (id == '-1') {
                $container.prepend($contact);
            } else if ($noticeCnt.length) {
                $noticeCnt.after($contact);
            } else {
                $container.prepend($contact);
            }

            $container.scrollTop(0);

        },

        appendMessage: function(message) {
            $('#nm-chat').append(nm.render.message(message));
        },

        afterMessage: function(message) {
            $('#nm-chat').prepend(nm.render.message(message));
        },

        sendMessage: function(mass) {

            if (nm.lockSend) return;

            var input = $('#nm-msg-field');
            var text  = input.val().trim();
            var to_id = nm.currContact.id;

            input.focus();

            if (!text) return;

            if (!mass) nm.topContact(to_id);

            nm.lockSend = true;
            nm.contactslock = true;
            nm.listenEnabled = false;

            var form_data = {
                contact_id: to_id,
                message: text,
                last_id: nm.messageLastId
            };

            if (mass) form_data.massmail = true;

            input.attr('disabled', 'disabled');
            $('#nm-composer .nm-buttons').addClass('sending');

            nm.post('sendMessage', form_data, function(data) {
                $('#nm-composer .nm-buttons').removeClass('sending');
                input.removeAttr('disabled').val('');
                nm.ls.remove('nm_draft_' + nm.user.id + '_' + nm.currContact.id);

                if (data.count > 0) {
                    $.each(data.messages, function() {
                        nm.appendMessage(this);
                        nm.messageLastId = this.id;
                    });

                    if (data.count > 1) {
                        nm.msgCounter = data.count;
                        nm.updateMsgCounter();
                    }

                    $('#nm-chat').waitForImages({
                        finished: function() {
                            nm.scrollChat();
                        },
                        waitForAll: true
                    });

                    input.focus();
                }

                nm.contactslock  = false;
                nm.listenEnabled = true;
                nm.lockSend = false;

                if (data.alert) {
                    core.alert(data.alert);
                }
            });
        },

        setMsgReaded: function(id) {

            var $contact = $('#nm-contact' + nm.currContact.id);
            var $counter = $('.counter', $contact);
            var count    = $counter.length ? $counter.attr('rel') : 0;

            nm.setMsgCounter(nm.currContact.id, --count);
            --nm.msgCounter;
            nm.updateMsgCounter();

            $('#nm-message-' + id).removeClass('new');
            nm.post('setMsgReaded', {message_id: id});
        },

        messDelete: function() {

            var message = $(this).closest('.conversation-item');
            var message_id = message.attr('rel');

            nm.post('delMessage', {message_id: message_id}, function(result) {
                if (result.error == false) {
                    message.css('background', '#FFAEAE').fadeOut(function() {
                        $(this).remove();
                    });
                }
            });

        },

        showOlder: function() {

            if (nm.older_loading) return;

            nm.older_loading = true;
            nm.contactslock  = true;

            var chat = $(this);

            chat.prepend('<div class="older-loading"></div>');

            nm.post('showOld', {contact_id: nm.currContact.id, message_first_id: nm.messageFirstId}, function(data) {

                chat.find('.older-loading').remove();

                if (data.messages.length) {
                    $.each(data.messages, function() {
                        nm.afterMessage(this);
                    });

                    var pos = chat.find('#nm-message-' + nm.messageFirstId).position();
                    chat.scrollTop(chat.scrollTop() + pos.top);
                }

                if (data.has_older) {
                    nm.messageFirstId = data.messages.length ? data.messages[data.messages.length - 1].id : 0;
                } else {
                    $('#nm-chat').unbind('scroll');
                    nm.messageFirstId = 0;
                }

                nm.contactslock  = false;
                nm.older_loading = false;

            });

        },

        contactDelete: function(contact) {

            var counter = contact.find('.counter');
            var contactId = contact.attr('rel');

            if (counter.length) {
                if (contactId > 0) {
                    core.alert('От контакта, который вы хотите удалить, есть непрочитанные сообщения. Прочитайте все новые сообщения, и затем удалите этот контакт.', 'Внимание!');
                } else {
                    core.alert('У вас остались непрочитанные уведомления.', 'Внимание!');
                }
            } else if (contact.hasClass('selected')) {
                core.alert('С контактом, который вы хотите удалить, в данный момент вы ведете переписку. Выберите другой контакт, и затем удалите этот.', 'Внимание!');
            } else {
                var confirm_msg = (contactId > 0) ? 'Вы уверены что хотите удалить контакт? (сообщения не удаляются, контакт убирается из списка)' : 'Вы уверены что хотите удалить все уведомления без возможности восстановления?';
                core.confirm(confirm_msg, null, function() {
                    nm.post('delContact', {contact_id: contactId}, function(result) {
                        if (result.error == false) {
                            contact.slideUp(function() {
                                $(this).remove();
                            });
                        }
                    });
                });
            }

        },

        scrollChat: function() {
            var $chat = $('#nm-chat');
            $chat.scrollTop($chat[0].scrollHeight);
        },

        updateDraft: function() {

            var text = $('#nm-msg-field').val();

            nm.ls.set('nm_draft_' + nm.user.id + '_' + nm.currContact.id, {
                text: text
            });

        },

        contactFilter: function() {

            var query = $('#nm-search-inp').val().trim();

            if (query.length) {
                $('#nm-userlist .user_contact:not(:Contains(' + query + ')):not(.selected)').slideUp();
                $('#nm-search-clr').show();
            } else {
                $('#nm-userlist .user_contact').slideDown();
                $('#nm-search-clr').hide();
            }

        },

        plural: function(count, form1, form2, form3) {
            var result = count%10==1&&count%100!=11?form1:(count%10>=2&&count%10<=4&&(count%100<10||count%100>=20)?form2:form3);
            return (result || '%d').replace('%d', count);
        },

        updateMsgCounter: function() {

            if (nm.msgCounter > 0) {
                if (nm.msgCounter > nm.oldMsgCount) {
                    nm.sound.play();
                }

                $.animateTitle(['*********************', 'У вас ' + nm.plural(nm.msgCounter, '%d непрочитанное сообщение', '%d непрочитанных сообщения', '%d непрочитанных сообщений')], 1000);

                if (!nm.my_mess.hasClass('has_new')) {
                    nm.my_mess.addClass('has_new');
                }

                if ((nm.my_mess.text()).search(/ \(\d+\)/) == -1) {
                    nm.my_mess.text(nm.my_mess.text() + ' (' + nm.msgCounter + ')');
                } else {
                    nm.my_mess.text((nm.my_mess.text()).replace(/ \(\d+\)/, ' (' + nm.msgCounter + ')'));
                }
            } else {
                $.animateTitle('clear');
                nm.my_mess.text((nm.my_mess.text()).replace(/ \(\d+\)/, ''));

                if (nm.my_mess.hasClass('has_new')) {
                    nm.my_mess.removeClass('has_new');
                }
            }

            nm.oldMsgCount = nm.msgCounter;

        },

        listen: function() {

            clearInterval(nm.listenTimer);

            nm.listenTimer = setTimeout(function() {
                if (nm.listenEnabled) {
                    if (nm.modal.visible && nm.currContact && nm.messageLastId) {
                        nm.post('getUpdate', {
                            contact_id: nm.currContact.id,
                            message_last_id: nm.messageLastId,
                            contact_last_id: nm.lastContactId
                        }, function(data) {
                            $.each(data.contacts, function() {
                                if (!$('#nm-contact' + this.id).length) {
                                    nm.addContact(this);
                                    nm.topContact(this.id);
                                } else {
                                    nm.setStatus(this.id, this.online);
                                    nm.setMsgCounter(this.id, this.new_messages);
                                }
                            });

                            if (data.new_messages.count > 0) {
                                $.each(data.new_messages.messages, function() {
                                    nm.appendMessage(this);
                                    nm.messageLastId = this.id;
                                });

                                $('#nm-chat').waitForImages({
                                    finished: function() {
                                        nm.scrollChat();
                                    },
                                    waitForAll: true
                                });
                            }

                            if (data.count_messages !== nm.oldMsgCount) {
                                nm.msgCounter = data.count_messages;
                                nm.updateMsgCounter();
                            }

                            nm.lastContactId = Math.max(nm.lastContactId, data.last_contact);
                            
                            nm.listen();
                        });
                    } else {
                        nm.post('getNewMessagesCount', {}, function(data) {
                            if (data.count !== nm.oldMsgCount) {
                                nm.msgCounter = data.count;
                                nm.updateMsgCounter();
                            }
                            nm.listen();
                        });
                    }
                } else {
                    nm.listen();
                }
            }, nm.listenInterval * 1000);
     
        },

        post: function(act, data, doneFunc, failFunc) {

            data.act = act;

            var request = $.ajax({
                url: nm.ajaxUrl,
                type: 'POST',
                data: data,
                dataType: 'json'
            });

            request.done(function(data) {
                if ($.isFunction(doneFunc)) {
                    doneFunc(data);
                }
            });

            request.fail(function() {
                if ($.isFunction(failFunc)) {
                    failFunc();
                }
            });

        },

        modal: {

            visible: false,

            show: function() {

                $('html').addClass('nm-opened');
                if (nm.isMobile) {
                    $('html').addClass('nm-mobile');
                }
                $('body').append(nm.render.mainModal());

                this.$el = $('#nm-dialog');
                this.$bg = $('#nm-overlay');

                this.$el.fadeIn();
                this.$bg.trigger('nm_opened');

                this.onDimensions();

                this.visible = true;

            },

            hide: function() {

                var self = this;

                this.$bg.trigger('nm_closed');
                this.$el.fadeOut(function() {
                    $('html').removeClass('nm-opened');
                    if (nm.isMobile) {
                        $('html').removeClass('nm-mobile');
                    }
                    $('#nm-dialog').remove();
                    self.$bg.remove();
                });

                this.visible = false;

            },

            onDimensions: function() {

                var headerHeight = 38; // Высота заголовка
                var searchHeight = 42; // Высота поиска
                var controlsHeight = $('#nm-composer').is(':visible') ? $('#nm-composer').outerHeight() : 0;
                var windowW = $(window).width();
                var windowH = $(window).height();
                var modalH = nm.modal.$el.height();
                var modalW = nm.modal.$el.width();

                $('#nm-chat').css({
                    height: modalH - headerHeight - controlsHeight
                });

                $('#nm-userlist').css({
                    height: modalH - headerHeight - searchHeight
                });

                if (nm.isMobile) return;

                var x = (windowH - modalH) / 2;
                var y = (windowW - modalW) / 2;

                nm.modal.$el.css({
                    top: x > 0 ? x : 0,
                    left: y > 0 ? y : 0
                });

            }

        },

        viewport: {

            content: 'width=device-width, initial-scale=1.0, maximum-scale=1.0, minimum-scale=1.0, user-scalable=no',

            init: function() {

                if (!nm.isMobile) return;

                this.meta = $('meta[name=viewport]');

                if (this.meta.length) {
                    this.default = this.meta.attr('content');
                } else {
                    this.meta = $('<meta name="viewport" content="">').appendTo('head');
                    this.default = '';
                }
            },

            change: function() {

                if (!nm.isMobile) return;

                var content = this.content;

                this.meta.attr('content', content);

            },

            restore: function() {

                if (!nm.isMobile) return;

                var content = this.default;

                this.meta.attr('content', content);

            }
        },

        emoji: {

            init: function() {

                var self = this;
                var $body = $(document.body);
                var $window = $(window);

                this.visible = false;

                this.$menu = $('<div>');
                this.$menu.addClass('emoji-menu');
                this.$menu.hide();

                this.$itemsWrap = $('<div class="emoji-items-wrap"></div>').appendTo(this.$menu);
                this.$items = $('<div class="emoji-items">').appendTo(this.$itemsWrap);

                $body.on('keydown', function(e) {
                    if (e.keyCode === KEY_ESC || e.keyCode === KEY_TAB) {
                        self.hide();
                    }
                });

                $body.on('mouseup', function(e) {
                    e = e.originalEvent || e;
                    var target = e.originalTarget || e.target || window;
                    while (target && target != window) {
                        target = target.parentNode;
                        if (target == self.$menu[0] || $('#nm-smiles-btn').length && target == $('#nm-smiles-btn')[0]) {
                            return;
                        }
                    }
                    self.hide();
                });

                this.$menu.on('mouseup', 'a', function(e) {
                    e.stopPropagation();
                    return false;
                });

                this.$menu.on('click', 'a', function(e) {
                    var emoji = $('.label', $(this)).text();
                    setTimeout(function() {
                        self.onItemSelected.apply(self, [emoji]);
                        if (e.ctrlKey || e.metaKey) {
                            self.hide();
                        }
                    }, 0);
                    e.stopPropagation();
                    return false;
                });

                this.load();
            },

            onItemSelected: function(emoji) {

                addSmile(emoji, 'nm-msg-field');

            },

            load: function() {

                var html = [];
                var options = nm.smilesList;
                var path = '/images/smilies/';
                var ext = '.gif';
                
                for (var key in options) {
                    if (options.hasOwnProperty(key)) {
                        var filename = options[key];
                        var name = filename.replace(ext, '');
                        html.push('<a href="javascript:void(0)" title="' + name + '"><img src="' + path + filename + '" alt="' + name + '"><span class="label">' + name + '</span></a>');
                    }
                }

                this.$items.html(html.join(''));

            },

            hide: function() {

                this.visible = false;
                this.$menu.hide().detach();

            },

            show: function() {

                this.$menu.appendTo('#nm-composer .usr_msg_bbcodebox');
                this.$menu.show();
                this.visible = true;

            },

            toggle: function() {

                this.visible ? this.hide() : this.show();

            }

        },

        sound: {

            audio: null,
            volume: 0.5,
            enabled: true,
            supported: true,

            init: function() {
                var ext;

                try {
                    this.audio = new Audio();

                    if (('no' != this.audio.canPlayType('audio/mpeg')) && ('' != this.audio.canPlayType('audio/mpeg'))) {
                        ext = '.mp3';
                    } else if (('no' != this.audio.canPlayType('audio/ogg; codecs="vorbis"')) && ('' != this.audio.canPlayType('audio/ogg; codecs="vorbis"'))) {
                        ext = '.ogg';
                    } else {
                        this.supported = false;
                    }

                    if (this.supported) {
                        this.audio.src = nm.soundName + ext;
                        this.audio.load();
                        this.audio.preload = "auto";
                        this.audio.volume = this.volume;
                    }

                } catch (e) {}
            },

            play: function() {
                if (this.supported && this.enabled) {
                    this.audio.play();
                }
            }
        },

        ls: {

            supported: function() {
                return (window.localStorage !== undefined && window.JSON !== undefined);
            },

            set: function(key, val) {
                this.remove(key);
                try {
                    return this.supported() ? localStorage.setItem(key, JSON.stringify(val)) : false;
                } catch (e) {
                    return false;
                }
            },

            get: function(key) {
                try {
                    return this.supported() ? JSON.parse(localStorage.getItem(key)) : false;
                } catch (e) {
                    return false;
                }
            },

            remove: function(key) {
                try { localStorage.removeItem(key); } catch(e) {}
            }

        },

        render: {

            mainModal: function() {

                return '' +
                '<div id="nm-overlay">' +
                    '<div id="nm-dialog" ' + (nm.isMobile ? 'class="mobile"' : '') + '>' +
                        '<div class="nm-header">' +
                            '<div class="nm-toggle"></div>' +
                            '<div class="nm-title">Моя переписка</div>' +
                            '<div class="nm-close" title="Закрыть окно"></div>' +
                        '</div>' +
                        '<div class="nm-body">' +
                            '<div class="nm-loading"></div>' +
                            '<div class="nm-nomess">Вы еще ни с кем не переписывались.</div>' +
                            '<div class="nm-content">' +
                                '<div class="nm-left">' +
                                    '<div class="nm-search-c-wrap">' +
                                        '<div class="nm-inp-c-bl">' +
                                            '<div class="nm-search-icon"></div>' +
                                            '<input type="text" id="nm-search-inp" value="" placeholder="Начните вводить имя...">' +
                                            '<div id="nm-search-clr" title="Сбросить фильтр"></div>' +
                                        '</div>' +
                                    '</div>' +
                                    '<ul id="nm-userlist"></ul>' +
                                '</div>' +
                                '<div class="nm-right">' +
                                    '<div id="nm-msg-loading"></div>' +
                                    '<div id="nm-chat-wrapper">' +
                                        '<div id="nm-chat" class="conversation-inner"></div>' +
                                        '<div id="nm-composer">' +
                                            '<div class="nm-editor">' +
                                                '<div class="usr_msg_bbcodebox">' +
                                                    nm.bbCodeToolBar +
                                                '</div>' +
                                                '<textarea id="nm-msg-field" placeholder="Введите текст сообщения"></textarea>' +
                                            '</div>' +
                                            '<div class="nm-buttons">' +
                                                '<button type="submit" id="nm-send" class="nm-submit">Отправить (' + (nm.sendOnEnter ? 'Enter' : 'Ctrl+Enter') + ')</button>' +
                                                (nm.user.is_admin ? '<button type="submit" id="nm-mass-send" class="nm-submit">Отправить всем</button>' : '') +
                                            '</div>' +
                                        '</div>' +
                                    '</div>' +
                                '</div>' +
                                '<div class="clearfix"></div>' +
                            '</div>' +
                        '</div>' +
                    '</div>' +
                '</div>';

            },

            contact: function(user) {

                return '' +
                  '<li id="nm-contact' + user.id + '" class="user_contact' + (user.online == 1 ? ' _online' : '') + '" rel="' + user.id + '" >' +
                    (user.new_messages > 0 ? '<span class="counter" rel="' + user.new_messages + '">+ ' + user.new_messages + '</span>' : '') +
                    '<span class="delete" title="Удалить контакт"></span>' +
                    '<div class="userpic">' +
                      (user.id > 0 ? '<a href="' + user.url + '" target="_blank" title="Перейти в профиль пользователя">' : '') +
                        '<img src="' + user.avatar + '" width="31" height="31" />' +
                        (user.id > 0 ? '<span class="online_status"></span>' : '') +
                      (user.id > 0 ? '</a>' : '') +
                    '</div>' +
                    '<div class="username" title="' + user.nickname + '">' + user.nickname + '</div>' +
                  '</li>';

            },

            message: function(msg) {

                var isMy = false,
                    avatar = nm.currContact.avatar,
                    nickname = nm.currContact.nickname;

                if (nm.user.id == msg.from_id) {
                    isMy = true;
                    avatar = nm.user.avatar;
                    nickname = nm.user.nickname;
                }

                var isNew = (msg.is_new == 1 && !isMy) ? true : false;

                return '' +
                  '<div id="nm-message-' + msg.id + '" class="conversation-item ' + (isMy ? 'item-right' : 'item-left') + (isNew ? ' new' : '') + ' clearfix" rel="' + msg.id + '">' +
                    '<div class="conversation-user">' +
                      '<img src="' + avatar + '" alt="" width="40" height="40">' +
                    '</div>' +
                    '<div class="conversation-body">' +
                      '<div class="author">' + nickname + ':</div>' +
                      '<div class="date">' + msg.senddate + '</div>' +
                      '<div class="delete" title="Удалить сообщение"></div>' +
                      '<div class="msg-content">' + msg.message + '</div>' +
                    '</div>' +
                  '</div>';

            }

        }

    };

    window.neomessenger = nm;

})(jQuery || $);